(*
 * OCamlSDL - An ML interface to the SDL library
 * Copyright (C) 1999  Frederic Brunel
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *)

(* $Id: sdltimer.mli,v 1.5 2005/04/09 12:36:15 oliv__a Exp $ *)

(** Time-related functions *)

(** Wait a specified number of milliseconds before returning *)
external delay : int -> unit = "sdltimer_delay"

(** Get the number of milliseconds since the SDL library initialization. *)
external get_ticks : unit -> int = "sdltimer_get_ticks" "noalloc"
